@@ -3,7 +3,7 @@ package com.fasterxml.jackson.databind.cfg;
 /**
  * Interface that actual SerializationFeature enumerations used by
  * {@link MapperConfig} implementations must implement.
- * Necessary since enums can not be extended using normal
+ * Necessary since enums cannot be extended using normal
  * inheritance, but can implement interfaces
  */
 public interface ConfigFeature
@@ -17,4 +17,11 @@ public interface ConfigFeature
      * Returns bit mask for this feature instance
      */
     public int getMask();
+
+    /**
+     * Convenience method for checking whether feature is enabled in given bitmask
+     * 
+     * @since 2.6
+     */
+    public boolean enabledIn(int flags);
 }
