@@ -1,6 +1,7 @@
 package com.fasterxml.jackson.databind.deser;
 
 import com.fasterxml.jackson.core.JsonLocation;
+import com.fasterxml.jackson.databind.util.ClassUtil;
 
 /**
  * Helper class for {@link UnresolvedForwardReference}, to contain information about unresolved ids.
@@ -31,6 +32,7 @@ public class UnresolvedId {
 
     @Override
     public String toString() {
-        return String.format("Object id [%s] (for %s) at %s", _id, _type, _location);
+        return String.format("Object id [%s] (for %s) at %s", _id,
+                ClassUtil.nameOf(_type), _location);
     }
-}
\ No newline at end of file
+}
