@@ -10,7 +10,7 @@ public class DelegatingExternalProperty1003Test extends BaseMapTest
 
         private final Hero hero;
 
-        private HeroBattle(Hero hero) {
+        HeroBattle(Hero hero) {
             if (hero == null) throw new Error();
             this.hero = hero;
         }
